You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@camel.apache.org by da...@apache.org on 2023/08/10 15:23:51 UTC

[camel] branch main updated: Fixed naming convention (#11059)

This is an automated email from the ASF dual-hosted git repository.

davsclaus pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/camel.git


The following commit(s) were added to refs/heads/main by this push:
     new 212536d1867 Fixed naming convention (#11059)
212536d1867 is described below

commit 212536d186760fddf3f097bec85008c30745d37a
Author: Vignesh Nayak Manel <vn...@gmail.com>
AuthorDate: Thu Aug 10 20:53:42 2023 +0530

    Fixed naming convention (#11059)
---
 .../catalog/components/aws2-step-functions.json    | 26 +++----
 .../aws2/stepfunctions/aws2-step-functions.json    | 26 +++----
 .../stepfunctions/StepFunctions2Constants.java     | 26 +++----
 .../dsl/StepFunctions2EndpointBuilderFactory.java  | 82 +++++++++++-----------
 4 files changed, 80 insertions(+), 80 deletions(-)

diff --git a/catalog/camel-catalog/src/generated/resources/org/apache/camel/catalog/components/aws2-step-functions.json b/catalog/camel-catalog/src/generated/resources/org/apache/camel/catalog/components/aws2-step-functions.json
index 5d6608196f6..26a7e95b4cd 100644
--- a/catalog/camel-catalog/src/generated/resources/org/apache/camel/catalog/components/aws2-step-functions.json
+++ b/catalog/camel-catalog/src/generated/resources/org/apache/camel/catalog/components/aws2-step-functions.json
@@ -44,24 +44,24 @@
     "secretKey": { "index": 19, "kind": "property", "displayName": "Secret Key", "group": "security", "label": "security", "required": false, "type": "string", "javaType": "java.lang.String", "deprecated": false, "autowired": false, "secret": true, "configurationClass": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Configuration", "configurationField": "configuration", "description": "Amazon AWS Secret Key" }
   },
   "headers": {
-    "CamelAwsStateMachineOperation": { "index": 0, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The operation we want to perform", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#OPERATION" },
+    "CamelAwsStepFunctionsOperation": { "index": 0, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The operation we want to perform", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#OPERATION" },
     "CamelAwsStepFunctionsStateMachineName": { "index": 1, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The name of the state machine", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#STATE_MACHINE_NAME" },
     "CamelAwsStepFunctionsStateMachineDefinition": { "index": 2, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The Amazon States Language definition of the state machine", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#STATE_MACHINE_DEFINITION" },
     "CamelAwsStepFunctionsStateMachineType": { "index": 3, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "Determines whether a Standard or Express state machine is created", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#STATE_MACHINE_TYPE" },
     "CamelAwsStepFunctionsStateMachineRoleArn": { "index": 4, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The Amazon Resource Name (ARN) of the IAM role to use for this state machine.", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#STATE_MACHINE_ROLE_ARN" },
     "CamelAwsStepFunctionsStateMachineArn": { "index": 5, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The Amazon Resource Name (ARN) of state machine.", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#STATE_MACHINE_ARN" },
-    "CamelAwsStateMachinesMaxResults": { "index": 6, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "Integer", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The limit number of results while listing state machines", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#STATE_MACHINES_MAX_RESULTS" },
-    "CamelAwsStepFunctionsStateMachineActivityName": { "index": 7, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The name of the state machine activity", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#ACTIVITY_NAME" },
-    "CamelAwsStepFunctionsStateMachineActivityArn": { "index": 8, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The ARN of the state machine activity", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#ACTIVITY_ARN" },
-    "CamelAwsStateMachineActivitiesMaxResults": { "index": 9, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "Integer", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The limit number of results while listing state machines", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#ACTIVITIES_MAX_RESULTS" },
-    "CamelAwsStateMachineExecutionArn": { "index": 10, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The Amazon Resource Name (ARN) of the execution.", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#EXECUTION_ARN" },
-    "CamelAwsStateMachineExecutionName": { "index": 11, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "Optional name of the execution.", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#EXECUTION_NAME" },
-    "CamelAwsStateMachineExecutionInput": { "index": 12, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The string that contains the JSON input data for the execution.", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#EXECUTION_INPUT" },
-    "CamelAwsStateMachineExecutionTraceHeader": { "index": 13, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "Passes the X-Ray trace header.", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#EXECUTION_TRACE_HEADER" },
-    "CamelAwsStateMachineExecutionHistoryMaxResults": { "index": 14, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "Integer", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The limit number of results while listing execution history", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#EXECUTION_HISTORY_MAX_RESULTS" },
-    "CamelAwsStateMachineExecutionHistoryIncludeExecutionData": { "index": 15, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "Boolean", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "You can select whether execution data (input or output of a history event) is returned.", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#EXECUTION_HISTORY_INCLUDE_ [...]
-    "CamelAwsStateMachineExecutionHistoryReverseOrder": { "index": 16, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "Boolean", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "Lists events in descending order of their timeStamp.", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#EXECUTION_HISTORY_REVERSE_ORDER" },
-    "CamelAwsStateMachineExecutionMaxResults": { "index": 17, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "Integer", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The limit number of results while listing executions", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#EXECUTIONS_MAX_RESULTS" }
+    "CamelAwsStepFunctionsStateMachinesMaxResults": { "index": 6, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "Integer", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The limit number of results while listing state machines", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#STATE_MACHINES_MAX_RESULTS" },
+    "CamelAwsStepFunctionsActivityName": { "index": 7, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The name of the state machine activity", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#ACTIVITY_NAME" },
+    "CamelAwsStepFunctionsActivityArn": { "index": 8, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The ARN of the state machine activity", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#ACTIVITY_ARN" },
+    "CamelAwsStepFunctionsActivitiesMaxResults": { "index": 9, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "Integer", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The limit number of results while listing state machines", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#ACTIVITIES_MAX_RESULTS" },
+    "CamelAwsStepFunctionsExecutionArn": { "index": 10, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The Amazon Resource Name (ARN) of the execution.", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#EXECUTION_ARN" },
+    "CamelAwsStepFunctionsExecutionName": { "index": 11, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "Optional name of the execution.", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#EXECUTION_NAME" },
+    "CamelAwsStepFunctionsExecutionInput": { "index": 12, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The string that contains the JSON input data for the execution.", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#EXECUTION_INPUT" },
+    "CamelAwsStepFunctionsExecutionTraceHeader": { "index": 13, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "Passes the X-Ray trace header.", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#EXECUTION_TRACE_HEADER" },
+    "CamelAwsStepFunctionsExecutionHistoryMaxResults": { "index": 14, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "Integer", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The limit number of results while listing execution history", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#EXECUTION_HISTORY_MAX_RESULTS" },
+    "CamelAwsStepFunctionsExecutionHistoryIncludeExecutionData": { "index": 15, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "Boolean", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "You can select whether execution data (input or output of a history event) is returned.", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#EXECUTION_HISTORY_INCLUDE [...]
+    "CamelAwsStepFunctionsExecutionHistoryReverseOrder": { "index": 16, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "Boolean", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "Lists events in descending order of their timeStamp.", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#EXECUTION_HISTORY_REVERSE_ORDER" },
+    "CamelAwsStepFunctionsExecutionMaxResults": { "index": 17, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "Integer", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The limit number of results while listing executions", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#EXECUTIONS_MAX_RESULTS" }
   },
   "properties": {
     "label": { "index": 0, "kind": "path", "displayName": "Label", "group": "producer", "label": "", "required": true, "type": "string", "javaType": "java.lang.String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "configurationClass": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Configuration", "configurationField": "configuration", "description": "Logical name" },
diff --git a/components/camel-aws/camel-aws2-step-functions/src/generated/resources/org/apache/camel/component/aws2/stepfunctions/aws2-step-functions.json b/components/camel-aws/camel-aws2-step-functions/src/generated/resources/org/apache/camel/component/aws2/stepfunctions/aws2-step-functions.json
index 5d6608196f6..26a7e95b4cd 100644
--- a/components/camel-aws/camel-aws2-step-functions/src/generated/resources/org/apache/camel/component/aws2/stepfunctions/aws2-step-functions.json
+++ b/components/camel-aws/camel-aws2-step-functions/src/generated/resources/org/apache/camel/component/aws2/stepfunctions/aws2-step-functions.json
@@ -44,24 +44,24 @@
     "secretKey": { "index": 19, "kind": "property", "displayName": "Secret Key", "group": "security", "label": "security", "required": false, "type": "string", "javaType": "java.lang.String", "deprecated": false, "autowired": false, "secret": true, "configurationClass": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Configuration", "configurationField": "configuration", "description": "Amazon AWS Secret Key" }
   },
   "headers": {
-    "CamelAwsStateMachineOperation": { "index": 0, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The operation we want to perform", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#OPERATION" },
+    "CamelAwsStepFunctionsOperation": { "index": 0, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The operation we want to perform", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#OPERATION" },
     "CamelAwsStepFunctionsStateMachineName": { "index": 1, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The name of the state machine", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#STATE_MACHINE_NAME" },
     "CamelAwsStepFunctionsStateMachineDefinition": { "index": 2, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The Amazon States Language definition of the state machine", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#STATE_MACHINE_DEFINITION" },
     "CamelAwsStepFunctionsStateMachineType": { "index": 3, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "Determines whether a Standard or Express state machine is created", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#STATE_MACHINE_TYPE" },
     "CamelAwsStepFunctionsStateMachineRoleArn": { "index": 4, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The Amazon Resource Name (ARN) of the IAM role to use for this state machine.", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#STATE_MACHINE_ROLE_ARN" },
     "CamelAwsStepFunctionsStateMachineArn": { "index": 5, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The Amazon Resource Name (ARN) of state machine.", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#STATE_MACHINE_ARN" },
-    "CamelAwsStateMachinesMaxResults": { "index": 6, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "Integer", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The limit number of results while listing state machines", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#STATE_MACHINES_MAX_RESULTS" },
-    "CamelAwsStepFunctionsStateMachineActivityName": { "index": 7, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The name of the state machine activity", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#ACTIVITY_NAME" },
-    "CamelAwsStepFunctionsStateMachineActivityArn": { "index": 8, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The ARN of the state machine activity", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#ACTIVITY_ARN" },
-    "CamelAwsStateMachineActivitiesMaxResults": { "index": 9, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "Integer", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The limit number of results while listing state machines", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#ACTIVITIES_MAX_RESULTS" },
-    "CamelAwsStateMachineExecutionArn": { "index": 10, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The Amazon Resource Name (ARN) of the execution.", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#EXECUTION_ARN" },
-    "CamelAwsStateMachineExecutionName": { "index": 11, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "Optional name of the execution.", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#EXECUTION_NAME" },
-    "CamelAwsStateMachineExecutionInput": { "index": 12, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The string that contains the JSON input data for the execution.", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#EXECUTION_INPUT" },
-    "CamelAwsStateMachineExecutionTraceHeader": { "index": 13, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "Passes the X-Ray trace header.", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#EXECUTION_TRACE_HEADER" },
-    "CamelAwsStateMachineExecutionHistoryMaxResults": { "index": 14, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "Integer", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The limit number of results while listing execution history", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#EXECUTION_HISTORY_MAX_RESULTS" },
-    "CamelAwsStateMachineExecutionHistoryIncludeExecutionData": { "index": 15, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "Boolean", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "You can select whether execution data (input or output of a history event) is returned.", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#EXECUTION_HISTORY_INCLUDE_ [...]
-    "CamelAwsStateMachineExecutionHistoryReverseOrder": { "index": 16, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "Boolean", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "Lists events in descending order of their timeStamp.", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#EXECUTION_HISTORY_REVERSE_ORDER" },
-    "CamelAwsStateMachineExecutionMaxResults": { "index": 17, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "Integer", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The limit number of results while listing executions", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#EXECUTIONS_MAX_RESULTS" }
+    "CamelAwsStepFunctionsStateMachinesMaxResults": { "index": 6, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "Integer", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The limit number of results while listing state machines", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#STATE_MACHINES_MAX_RESULTS" },
+    "CamelAwsStepFunctionsActivityName": { "index": 7, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The name of the state machine activity", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#ACTIVITY_NAME" },
+    "CamelAwsStepFunctionsActivityArn": { "index": 8, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The ARN of the state machine activity", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#ACTIVITY_ARN" },
+    "CamelAwsStepFunctionsActivitiesMaxResults": { "index": 9, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "Integer", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The limit number of results while listing state machines", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#ACTIVITIES_MAX_RESULTS" },
+    "CamelAwsStepFunctionsExecutionArn": { "index": 10, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The Amazon Resource Name (ARN) of the execution.", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#EXECUTION_ARN" },
+    "CamelAwsStepFunctionsExecutionName": { "index": 11, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "Optional name of the execution.", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#EXECUTION_NAME" },
+    "CamelAwsStepFunctionsExecutionInput": { "index": 12, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The string that contains the JSON input data for the execution.", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#EXECUTION_INPUT" },
+    "CamelAwsStepFunctionsExecutionTraceHeader": { "index": 13, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "Passes the X-Ray trace header.", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#EXECUTION_TRACE_HEADER" },
+    "CamelAwsStepFunctionsExecutionHistoryMaxResults": { "index": 14, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "Integer", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The limit number of results while listing execution history", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#EXECUTION_HISTORY_MAX_RESULTS" },
+    "CamelAwsStepFunctionsExecutionHistoryIncludeExecutionData": { "index": 15, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "Boolean", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "You can select whether execution data (input or output of a history event) is returned.", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#EXECUTION_HISTORY_INCLUDE [...]
+    "CamelAwsStepFunctionsExecutionHistoryReverseOrder": { "index": 16, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "Boolean", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "Lists events in descending order of their timeStamp.", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#EXECUTION_HISTORY_REVERSE_ORDER" },
+    "CamelAwsStepFunctionsExecutionMaxResults": { "index": 17, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "Integer", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The limit number of results while listing executions", "constantName": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Constants#EXECUTIONS_MAX_RESULTS" }
   },
   "properties": {
     "label": { "index": 0, "kind": "path", "displayName": "Label", "group": "producer", "label": "", "required": true, "type": "string", "javaType": "java.lang.String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "configurationClass": "org.apache.camel.component.aws2.stepfunctions.StepFunctions2Configuration", "configurationField": "configuration", "description": "Logical name" },
diff --git a/components/camel-aws/camel-aws2-step-functions/src/main/java/org/apache/camel/component/aws2/stepfunctions/StepFunctions2Constants.java b/components/camel-aws/camel-aws2-step-functions/src/main/java/org/apache/camel/component/aws2/stepfunctions/StepFunctions2Constants.java
index 8f653fa0095..438dcc35e32 100644
--- a/components/camel-aws/camel-aws2-step-functions/src/main/java/org/apache/camel/component/aws2/stepfunctions/StepFunctions2Constants.java
+++ b/components/camel-aws/camel-aws2-step-functions/src/main/java/org/apache/camel/component/aws2/stepfunctions/StepFunctions2Constants.java
@@ -21,7 +21,7 @@ import org.apache.camel.spi.Metadata;
 public interface StepFunctions2Constants {
 
     @Metadata(description = "The operation we want to perform", javaType = "String")
-    String OPERATION = "CamelAwsStateMachineOperation";
+    String OPERATION = "CamelAwsStepFunctionsOperation";
 
     @Metadata(description = "The name of the state machine", javaType = "String")
     String STATE_MACHINE_NAME = "CamelAwsStepFunctionsStateMachineName";
@@ -40,40 +40,40 @@ public interface StepFunctions2Constants {
     String STATE_MACHINE_ARN = "CamelAwsStepFunctionsStateMachineArn";
 
     @Metadata(description = "The limit number of results while listing state machines", javaType = "Integer")
-    String STATE_MACHINES_MAX_RESULTS = "CamelAwsStateMachinesMaxResults";
+    String STATE_MACHINES_MAX_RESULTS = "CamelAwsStepFunctionsStateMachinesMaxResults";
 
     @Metadata(description = "The name of the state machine activity", javaType = "String")
-    String ACTIVITY_NAME = "CamelAwsStepFunctionsStateMachineActivityName";
+    String ACTIVITY_NAME = "CamelAwsStepFunctionsActivityName";
 
     @Metadata(description = "The ARN of the state machine activity", javaType = "String")
-    String ACTIVITY_ARN = "CamelAwsStepFunctionsStateMachineActivityArn";
+    String ACTIVITY_ARN = "CamelAwsStepFunctionsActivityArn";
 
     @Metadata(description = "The limit number of results while listing state machines", javaType = "Integer")
-    String ACTIVITIES_MAX_RESULTS = "CamelAwsStateMachineActivitiesMaxResults";
+    String ACTIVITIES_MAX_RESULTS = "CamelAwsStepFunctionsActivitiesMaxResults";
 
     @Metadata(description = "The Amazon Resource Name (ARN) of the execution.", javaType = "String")
-    String EXECUTION_ARN = "CamelAwsStateMachineExecutionArn";
+    String EXECUTION_ARN = "CamelAwsStepFunctionsExecutionArn";
 
     @Metadata(description = "Optional name of the execution.", javaType = "String")
-    String EXECUTION_NAME = "CamelAwsStateMachineExecutionName";
+    String EXECUTION_NAME = "CamelAwsStepFunctionsExecutionName";
 
     @Metadata(description = "The string that contains the JSON input data for the execution.", javaType = "String")
-    String EXECUTION_INPUT = "CamelAwsStateMachineExecutionInput";
+    String EXECUTION_INPUT = "CamelAwsStepFunctionsExecutionInput";
 
     @Metadata(description = "Passes the X-Ray trace header.", javaType = "String")
-    String EXECUTION_TRACE_HEADER = "CamelAwsStateMachineExecutionTraceHeader";
+    String EXECUTION_TRACE_HEADER = "CamelAwsStepFunctionsExecutionTraceHeader";
 
     @Metadata(description = "The limit number of results while listing execution history", javaType = "Integer")
-    String EXECUTION_HISTORY_MAX_RESULTS = "CamelAwsStateMachineExecutionHistoryMaxResults";
+    String EXECUTION_HISTORY_MAX_RESULTS = "CamelAwsStepFunctionsExecutionHistoryMaxResults";
 
     @Metadata(description = "You can select whether execution data (input or output of a history event) is returned.",
               javaType = "Boolean")
-    String EXECUTION_HISTORY_INCLUDE_EXECUTION_DATA = "CamelAwsStateMachineExecutionHistoryIncludeExecutionData";
+    String EXECUTION_HISTORY_INCLUDE_EXECUTION_DATA = "CamelAwsStepFunctionsExecutionHistoryIncludeExecutionData";
 
     @Metadata(description = "Lists events in descending order of their timeStamp.", javaType = "Boolean")
-    String EXECUTION_HISTORY_REVERSE_ORDER = "CamelAwsStateMachineExecutionHistoryReverseOrder";
+    String EXECUTION_HISTORY_REVERSE_ORDER = "CamelAwsStepFunctionsExecutionHistoryReverseOrder";
 
     @Metadata(description = "The limit number of results while listing executions", javaType = "Integer")
-    String EXECUTIONS_MAX_RESULTS = "CamelAwsStateMachineExecutionMaxResults";
+    String EXECUTIONS_MAX_RESULTS = "CamelAwsStepFunctionsExecutionMaxResults";
 
 }
diff --git a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/StepFunctions2EndpointBuilderFactory.java b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/StepFunctions2EndpointBuilderFactory.java
index 3030ff52f08..c61aa31516c 100644
--- a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/StepFunctions2EndpointBuilderFactory.java
+++ b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/StepFunctions2EndpointBuilderFactory.java
@@ -575,10 +575,10 @@ public interface StepFunctions2EndpointBuilderFactory {
          * 
          * Group: producer
          * 
          * @return the name of the header {@code AwsStateMachineOperation}.
          */
-        public String awsStateMachineOperation() {
-            return "AwsStateMachineOperation";
+        public String awsStepFunctionsOperation() {
+            return "AwsStepFunctionsOperation";
         }
 
         /**
@@ -659,10 +659,11 @@ public interface StepFunctions2EndpointBuilderFactory {
          * 
          * Group: producer
          * 
          * @return the name of the header {@code AwsStateMachinesMaxResults}.
          */
-        public String awsStateMachinesMaxResults() {
-            return "AwsStateMachinesMaxResults";
+        public String awsStepFunctionsStateMachinesMaxResults() {
+            return "AwsStepFunctionsStateMachinesMaxResults";
         }
 
         /**
@@ -672,11 +673,10 @@ public interface StepFunctions2EndpointBuilderFactory {
          * 
          * Group: producer
          * 
          * @return the name of the header {@code
          * AwsStepFunctionsStateMachineActivityName}.
          */
-        public String awsStepFunctionsStateMachineActivityName() {
-            return "AwsStepFunctionsStateMachineActivityName";
+        public String awsStepFunctionsActivityName() {
+            return "AwsStepFunctionsActivityName";
         }
 
         /**
@@ -686,11 +686,10 @@ public interface StepFunctions2EndpointBuilderFactory {
          * 
          * Group: producer
          * 
          * @return the name of the header {@code
          * AwsStepFunctionsStateMachineActivityArn}.
          */
-        public String awsStepFunctionsStateMachineActivityArn() {
-            return "AwsStepFunctionsStateMachineActivityArn";
+        public String awsStepFunctionsActivityArn() {
+            return "AwsStepFunctionsActivityArn";
         }
 
         /**
@@ -701,10 +700,10 @@ public interface StepFunctions2EndpointBuilderFactory {
          * Group: producer
          * 
          * @return the name of the header {@code
-         * AwsStateMachineActivitiesMaxResults}.
+         * AwsStepFunctionsActivitiesMaxResults}.
          */
-        public String awsStateMachineActivitiesMaxResults() {
-            return "AwsStateMachineActivitiesMaxResults";
+        public String awsStepFunctionsActivitiesMaxResults() {
+            return "AwsStepFunctionsActivitiesMaxResults";
         }
 
         /**
@@ -714,10 +713,10 @@ public interface StepFunctions2EndpointBuilderFactory {
          * 
          * Group: producer
          * 
          * @return the name of the header {@code AwsStateMachineExecutionArn}.
          */
-        public String awsStateMachineExecutionArn() {
-            return "AwsStateMachineExecutionArn";
+        public String awsStepFunctionsExecutionArn() {
+            return "AwsStepFunctionsExecutionArn";
         }
 
         /**
@@ -727,10 +726,10 @@ public interface StepFunctions2EndpointBuilderFactory {
          * 
          * Group: producer
          * 
          * @return the name of the header {@code AwsStateMachineExecutionName}.
          */
-        public String awsStateMachineExecutionName() {
-            return "AwsStateMachineExecutionName";
+        public String awsStepFunctionsExecutionName() {
+            return "AwsStepFunctionsExecutionName";
         }
 
         /**
@@ -740,10 +739,11 @@ public interface StepFunctions2EndpointBuilderFactory {
          * 
          * Group: producer
          * 
          * @return the name of the header {@code AwsStateMachineExecutionInput}.
          */
-        public String awsStateMachineExecutionInput() {
-            return "AwsStateMachineExecutionInput";
+        public String awsStepFunctionsExecutionInput() {
+            return "AwsStepFunctionsExecutionInput";
         }
 
         /**
@@ -754,10 +754,10 @@ public interface StepFunctions2EndpointBuilderFactory {
          * Group: producer
          * 
          * @return the name of the header {@code
-         * AwsStateMachineExecutionTraceHeader}.
+         * AwsStepFunctionsExecutionTraceHeader}.
          */
-        public String awsStateMachineExecutionTraceHeader() {
-            return "AwsStateMachineExecutionTraceHeader";
+        public String awsStepFunctionsExecutionTraceHeader() {
+            return "AwsStepFunctionsExecutionTraceHeader";
         }
 
         /**
@@ -768,10 +768,10 @@ public interface StepFunctions2EndpointBuilderFactory {
          * Group: producer
          * 
          * @return the name of the header {@code
-         * AwsStateMachineExecutionHistoryMaxResults}.
+         * AwsStepFunctionsExecutionHistoryMaxResults}.
          */
-        public String awsStateMachineExecutionHistoryMaxResults() {
-            return "AwsStateMachineExecutionHistoryMaxResults";
+        public String awsStepFunctionsExecutionHistoryMaxResults() {
+            return "AwsStepFunctionsExecutionHistoryMaxResults";
         }
 
         /**
@@ -783,10 +783,10 @@ public interface StepFunctions2EndpointBuilderFactory {
          * Group: producer
          * 
          * @return the name of the header {@code
-         * AwsStateMachineExecutionHistoryIncludeExecutionData}.
+         * AwsStepFunctionsExecutionHistoryIncludeExecutionData}.
          */
-        public String awsStateMachineExecutionHistoryIncludeExecutionData() {
-            return "AwsStateMachineExecutionHistoryIncludeExecutionData";
+        public String awsStepFunctionsExecutionHistoryIncludeExecutionData() {
+            return "AwsStepFunctionsExecutionHistoryIncludeExecutionData";
         }
 
         /**
@@ -797,10 +797,10 @@ public interface StepFunctions2EndpointBuilderFactory {
          * Group: producer
          * 
          * @return the name of the header {@code
-         * AwsStateMachineExecutionHistoryReverseOrder}.
+         * AwsStepFunctionsExecutionHistoryReverseOrder}.
          */
-        public String awsStateMachineExecutionHistoryReverseOrder() {
-            return "AwsStateMachineExecutionHistoryReverseOrder";
+        public String awsStepFunctionsExecutionHistoryReverseOrder() {
+            return "AwsStepFunctionsExecutionHistoryReverseOrder";
         }
 
         /**
@@ -811,10 +811,10 @@ public interface StepFunctions2EndpointBuilderFactory {
          * Group: producer
          * 
          * @return the name of the header {@code
-         * AwsStateMachineExecutionMaxResults}.
+         * AwsStepFunctionsExecutionMaxResults}.
          */
-        public String awsStateMachineExecutionMaxResults() {
-            return "AwsStateMachineExecutionMaxResults";
+        public String awsStepFunctionsExecutionMaxResults() {
+            return "AwsStepFunctionsExecutionMaxResults";
         }
     }
     static StepFunctions2EndpointBuilder endpointBuilder(
@@ -575,10 +575,10 @@ public interface StepFunctions2EndpointBuilderFactory {
          * Group: producer
          * 
-         * @return the name of the header {@code AwsStateMachineOperation}.
+         * @return the name of the header {@code AwsStepFunctionsOperation}.
          */
@@ -659,10 +659,11 @@ public interface StepFunctions2EndpointBuilderFactory {
          * Group: producer
          * 
-         * @return the name of the header {@code AwsStateMachinesMaxResults}.
+         * @return the name of the header {@code
+         * AwsStepFunctionsStateMachinesMaxResults}.
          */
@@ -672,11 +673,10 @@ public interface StepFunctions2EndpointBuilderFactory {
          * Group: producer
          * 
-         * @return the name of the header {@code
-         * AwsStepFunctionsStateMachineActivityName}.
+         * @return the name of the header {@code AwsStepFunctionsActivityName}.
          */
@@ -686,11 +686,10 @@ public interface StepFunctions2EndpointBuilderFactory {
          * Group: producer
          * 
-         * @return the name of the header {@code
-         * AwsStepFunctionsStateMachineActivityArn}.
+         * @return the name of the header {@code AwsStepFunctionsActivityArn}.
          */
@@ -714,10 +713,10 @@ public interface StepFunctions2EndpointBuilderFactory {
          * Group: producer
          * 
-         * @return the name of the header {@code AwsStateMachineExecutionArn}.
+         * @return the name of the header {@code AwsStepFunctionsExecutionArn}.
          */
@@ -727,10 +726,10 @@ public interface StepFunctions2EndpointBuilderFactory {
          * Group: producer
          * 
-         * @return the name of the header {@code AwsStateMachineExecutionName}.
+         * @return the name of the header {@code AwsStepFunctionsExecutionName}.
          */
@@ -740,10 +739,11 @@ public interface StepFunctions2EndpointBuilderFactory {
          * Group: producer
          * 
-         * @return the name of the header {@code AwsStateMachineExecutionInput}.
+         * @return the name of the header {@code
+         * AwsStepFunctionsExecutionInput}.
          */